==> open-cluster-management-observability-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/shared/ObservabilityAddonSpecFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObservabilityAddonSpecFluentImpl<A extends ObservabilityAddonSpecFluent<A>> extends BaseFluent<A> implements ObservabilityAddonSpecFluent<A>{
  public ObservabilityAddonSpecFluentImpl() {
  }
  public ObservabilityAddonSpecFluentImpl(ObservabilityAddonSpec instance) {
    this.withEnableMetrics(instance.getEnableMetrics()); 
    this.withInterval(instance.getInterval()); 
    this.withResources(instance.getResources()); 
  }
  private Boolean enableMetrics;
  private Integer interval;
  private ResourceRequirementsBuilder resources;
  public Boolean getEnableMetrics() {
    return this.enableMetrics;
  }
  public A withEnableMetrics(Boolean enableMetrics) {
    this.enableMetrics=enableMetrics; return (A) this;
  }
  public Boolean hasEnableMetrics() {
    return this.enableMetrics != null;
  }
  public Integer getInterval() {
    return this.interval;
  }
  public A withInterval(Integer interval) {
    this.interval=interval; return (A) this;
  }
  public Boolean hasInterval() {
    return this.interval != null;
  }
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceRequirements getResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public ResourceRequirements buildResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public A withResources(ResourceRequirements resources) {
    _visitables.get("resources").remove(this.resources);
    if (resources!=null){ this.resources= new ResourceRequirementsBuilder(resources); _visitables.get("resources").add(this.resources);} else { this.resources = null; _visitables.get("resources").remove(this.resources); } return (A) this;
  }
  public Boolean hasResources() {
    return this.resources != null;
  }
  public ObservabilityAddonSpecFluent.ResourcesNested<A> withNewResources() {
    return new ObservabilityAddonSpecFluentImpl.ResourcesNestedImpl();
  }
  public ObservabilityAddonSpecFluent.ResourcesNested<A> withNewResourcesLike(ResourceRequirements item) {
    return new ObservabilityAddonSpecFluentImpl.ResourcesNestedImpl(item);
  }
  public ObservabilityAddonSpecFluent.ResourcesNested<A> editResources() {
    return withNewResourcesLike(getResources());
  }
  public ObservabilityAddonSpecFluent.ResourcesNested<A> editOrNewResources() {
    return withNewResourcesLike(getResources() != null ? getResources(): new ResourceRequirementsBuilder().build());
  }
  public ObservabilityAddonSpecFluent.ResourcesNested<A> editOrNewResourcesLike(ResourceRequirements item) {
    return withNewResourcesLike(getResources() != null ? getResources(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObservabilityAddonSpecFluentImpl that = (ObservabilityAddonSpecFluentImpl) o;
    if (enableMetrics != null ? !enableMetrics.equals(that.enableMetrics) :that.enableMetrics != null) return false;
    if (interval != null ? !interval.equals(that.interval) :that.interval != null) return false;
    if (resources != null ? !resources.equals(that.resources) :that.resources != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enableMetrics,  interval,  resources,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enableMetrics != null) { sb.append("enableMetrics:"); sb.append(enableMetrics + ","); }
    if (interval != null) { sb.append("interval:"); sb.append(interval + ","); }
    if (resources != null) { sb.append("resources:"); sb.append(resources); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnableMetrics() {
    return withEnableMetrics(true);
  }
  class ResourcesNestedImpl<N> extends ResourceRequirementsFluentImpl<ObservabilityAddonSpecFluent.ResourcesNested<N>> implements ObservabilityAddonSpecFluent.ResourcesNested<N>,Nested<N>{
    ResourcesNestedImpl(ResourceRequirements item) {
      this.builder = new ResourceRequirementsBuilder(this, item);
    }
    ResourcesNestedImpl() {
      this.builder = new ResourceRequirementsBuilder(this);
    }
    ResourceRequirementsBuilder builder;
    public N and() {
      return (N) ObservabilityAddonSpecFluentImpl.this.withResources(builder.build());
    }
    public N endResources() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-observability-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/shared/ObservabilityAddonSpecFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObservabilityAddonSpecFluentImpl<A extends ObservabilityAddonSpecFluent<A>> extends BaseFluent<A> implements ObservabilityAddonSpecFluent<A>{
  public ObservabilityAddonSpecFluentImpl() {
  }
  public ObservabilityAddonSpecFluentImpl(ObservabilityAddonSpec instance) {
    if (instance != null) {
      this.withEnableMetrics(instance.getEnableMetrics());
      this.withInterval(instance.getInterval());
      this.withResources(instance.getResources());
    }
  }
  private Boolean enableMetrics;
  private Integer interval;
  private ResourceRequirementsBuilder resources;
  public Boolean getEnableMetrics() {
    return this.enableMetrics;
  }
  public A withEnableMetrics(Boolean enableMetrics) {
    this.enableMetrics=enableMetrics; return (A) this;
  }
  public Boolean hasEnableMetrics() {
    return this.enableMetrics != null;
  }
  public Integer getInterval() {
    return this.interval;
  }
  public A withInterval(Integer interval) {
    this.interval=interval; return (A) this;
  }
  public Boolean hasInterval() {
    return this.interval != null;
  }
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceRequirements getResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public ResourceRequirements buildResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public A withResources(ResourceRequirements resources) {
    _visitables.get("resources").remove(this.resources);
    if (resources!=null){ this.resources= new ResourceRequirementsBuilder(resources); _visitables.get("resources").add(this.resources);} else { this.resources = null; _visitables.get("resources").remove(this.resources); } return (A) this;
  }
  public Boolean hasResources() {
    return this.resources != null;
  }
  public ObservabilityAddonSpecFluentImpl.ResourcesNested<A> withNewResources() {
    return new ObservabilityAddonSpecFluentImpl.ResourcesNestedImpl();
  }
  public ObservabilityAddonSpecFluentImpl.ResourcesNested<A> withNewResourcesLike(ResourceRequirements item) {
    return new ObservabilityAddonSpecFluentImpl.ResourcesNestedImpl(item);
  }
  public ObservabilityAddonSpecFluentImpl.ResourcesNested<A> editResources() {
    return withNewResourcesLike(getResources());
  }
  public ObservabilityAddonSpecFluentImpl.ResourcesNested<A> editOrNewResources() {
    return withNewResourcesLike(getResources() != null ? getResources(): new ResourceRequirementsBuilder().build());
  }
  public ObservabilityAddonSpecFluentImpl.ResourcesNested<A> editOrNewResourcesLike(ResourceRequirements item) {
    return withNewResourcesLike(getResources() != null ? getResources(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObservabilityAddonSpecFluentImpl that = (ObservabilityAddonSpecFluentImpl) o;
    if (!java.util.Objects.equals(enableMetrics, that.enableMetrics)) return false;

    if (!java.util.Objects.equals(interval, that.interval)) return false;

    if (!java.util.Objects.equals(resources, that.resources)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enableMetrics,  interval,  resources,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enableMetrics != null) { sb.append("enableMetrics:"); sb.append(enableMetrics + ","); }
    if (interval != null) { sb.append("interval:"); sb.append(interval + ","); }
    if (resources != null) { sb.append("resources:"); sb.append(resources); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnableMetrics() {
    return withEnableMetrics(true);
  }
  class ResourcesNestedImpl<N> extends ResourceRequirementsFluentImpl<ObservabilityAddonSpecFluentImpl.ResourcesNested<N>> implements ObservabilityAddonSpecFluentImpl.ResourcesNested<N>,Nested<N>{
    ResourcesNestedImpl(ResourceRequirements item) {
      this.builder = new ResourceRequirementsBuilder(this, item);
    }
    ResourcesNestedImpl() {
      this.builder = new ResourceRequirementsBuilder(this);
    }
    ResourceRequirementsBuilder builder;
    public N and() {
      return (N) ObservabilityAddonSpecFluentImpl.this.withResources(builder.build());
    }
    public N endResources() {
      return and();
    }
    
  }
  
}
